/**
   @file
   @ingroup interface
*/

#include <bpm/bpm_interface.h>
#include <bpm/bpm_messages.h>
#include <bpm/bpm_version.h>

int load_signals( char *fname, bpmsignal_t **sigs ) {

  if ( ! fname  || ! sigs ) {
    bpm_error( "Invalid pointer in load_signals(...)",
	       __FILE__, __LINE__ );
    return BPM_FAILURE;
  }

  /*--------------------------------------------------------------------------
    Loop over the events and bpms and load the waveforms
    --------------------------------------------------------------------------
  */
  
  int ibpm, ievt = 0, s;

  FILE *f = fopen( fname, "r" );
  if ( !f ) {
    char buf[255];
    sprintf(buf, "Unable to open file \"%s\" for reading in load_signals(...)", fname);
    bpm_error( buf, __FILE__, __LINE__ );
    return BPM_FAILURE;
  }

  // Header first - abuse get_header a little
  double ver;
  int num_evts;
  get_header( f, &ver, &num_evts );

  if (ver != BPM_VERSION_VAL) {
    bpm_warning("Incorrect version number in load_signals(...)", 
		__FILE__, __LINE__ );
  }

  *sigs = (bpmsignal_t*) calloc( num_evts, sizeof(bpmsignal_t) );

  // Now load in the events  
  char line[2000];
  char *tok;

  while ( fgets( line, 2000, f ) != NULL ) {

    // Check for comments
    tok = strtok( line, " " );
    if (tok[0] == '#') continue;

    // Assume this is an event - first number is ns
    (*sigs)[ievt].ns = atoi(tok);
    //    printf("%d %d\n", ievt, (*sigs)[ievt].ns);
    (*sigs)[ievt].wf = (int*) calloc( (*sigs)[ievt].ns, sizeof(int) );

    for (s = 0; s < (*sigs)[ievt].ns; s++) {
      tok = strtok( NULL, " " );
      (*sigs)[ievt].wf[s] = atoi(tok);
    }

    ievt++;
  }

  fclose(f);
  return BPM_SUCCESS;
}
