/**
   @file
   @ingroup orbit
*/
#include <bpm/bpm_messages.h>
#include <bpm/bpm_orbit.h>

int generate_corr_scan(  bpmconf_t* bpm, beamconf_t* beam, int num_evts,
			 int num_steps, double angle_range, double angle,
			 double z_pos ) {

  if ( ! bpm ) {
    bpm_error( "Invalid pointer arguments in generate_corr_scan(...)",
               __FILE__, __LINE__ ); 
    return BPM_FAILURE;
  }

  if ( ! beam ) {
    bpm_error( "Invalid pointer arguments in generate_corr_scan(...)",
               __FILE__, __LINE__ ); 
    return BPM_FAILURE;
  }

  if ( num_evts == 0 ) {
    bpm_warning( "Zero events given as an argument to generate_corr_scan(...)",
               __FILE__, __LINE__ ); 
    return BPM_FAILURE;
  }

  if ( num_steps == 0 ) {
    bpm_error( "Zero steps given as an argument to generate_corr_scan(...)",
               __FILE__, __LINE__ ); 
    return BPM_FAILURE;
  }
  
  double step = 0;
  int evt = 0;
  double z_diff = bpm->geom_pos[2] - z_pos;
  angle *= 1.e-6;
  z_diff *= 1.e6; // Change to microns from metres

  // Loop over the events and generate the positions
  for (evt = 0; evt < num_evts * num_steps; evt++ ) {

    double curr_angle = -angle_range / 2. + step * angle_range / (double) (num_steps - 1);
    curr_angle *= 1.e-6;

    beam[evt].beampos[0] += cos( angle ) * z_diff * tan( curr_angle );
    beam[evt].beampos[1] += sin( angle ) * z_diff * tan( curr_angle );
    beam[evt].beamslope[0] += curr_angle * 1.e6;
    beam[evt].beamslope[1] += angle * 1.e6;

    if ( (( evt % num_evts ) == 0) && ( evt > 0 )) step++;

  }
    
  return BPM_SUCCESS;
}
