/**
   @file
   @ingroup orbit
*/
#include <bpm/bpm_messages.h>
#include <bpm/bpm_orbit.h>

int generate_mover_scan(  beamconf_t* beam, int num_evts, int num_steps, 
			  double mover_range, double angle ) {

  if ( ! beam ) {
    bpm_error( "Invalid pointer arguments in generate_mover_scan(...)",
               __FILE__, __LINE__ ); 
    return BPM_FAILURE;
  }

  if ( num_evts == 0 ) {
    bpm_warning( "Zero events given as an argument to generate_mover_scan(...)",
               __FILE__, __LINE__ ); 
    return BPM_FAILURE;
  }

  if ( num_steps == 0 ) {
    bpm_error( "Zero steps given as an argument to generate_mover_scan(...)",
               __FILE__, __LINE__ ); 
    return BPM_FAILURE;
  }
  
  double step = 0;
  int evt = 0;
  angle *= 1.e-6;

  // Loop over the events and generate the positions
  for (evt = 0; evt < num_evts * num_steps; evt++ ) {
    double curr_move = -mover_range / 2. + step * mover_range / (double) (num_steps - 1);

    // Note the negative - a bpm move causes the beam to move in the opposite direction
    beam[evt].beampos[0] -= cos( angle ) * curr_move;
    beam[evt].beampos[1] -= sin( angle ) * curr_move;

    if ( (( evt % num_evts ) == 0) && ( evt > 0 )) step++;
  }
    
  return BPM_SUCCESS;
}
