/**
   @file
   @ingroup processing
*/

#include <math.h>
#include <bpm/bpm_messages.h>
#include <bpm/bpm_process.h>

/**
   Performs the DDC on the input waveform
   
   @param wf input waveform (with the pedestal substracted!)
   @param ns number of samples in the waveform
   @param fs sampling frequency
   @param freq frequency of the signal
   @param t0 sampling point
   @param out complex output DDC waveform
   
*/
int downmix_waveform( double *wf, int ns, double fs, double freq, double t0, double **out ) {


  int i;
  double ti, ped, rms;

  if ( ! wf || ! out ) {
    bpm_error( "Invalid pointer arguments in downmix_waveform(...)",
	       __FILE__, __LINE__ );
    return BPM_FAILURE;
  }

  // get pedestal
  //if ( get_pedestal( wf, ns, 20, &ped, &rms ) == BPM_FAILURE ) {
  //  bpm_error( "Unable to retreive the pedestal in downmix_waveform(...)",
  //	       __FILE__, __LINE__ );
  //  return BPM_FAILURE;
  //}

  // dowmixing
  for ( i=0; i<ns; i++ ) {
    //if ( sample_to_time( fs, ns, i, &ti ) == BPM_FAILURE ) {
    //  bpm_error( "Unable to convert sample to time in downmix_waveform(...)",
//		 __FILE__, __LINE__ );
    //  return BPM_FAILURE;
    //}

    out[i][Re] = wf[i] * cos( 2. * PI * freq * i / fs );
    out[i][Im] = wf[i] * sin( 2. * PI * freq * i / fs );
  }

  return BPM_SUCCESS;
}
