/**
   @file
   @ingroup processing
*/
#include <stdio.h>
#include <bpm/bpm_messages.h>
#include <bpm/bpm_process.h>

/**
   This routine processes a diode pulse, which should be found in the
   signal structure. It fills the proc structure with the t0. 

   @param bpm  The bpm configuration structure
   @param sig  The bpm signal
   @param proc The processed waveform structure

   @return BPM_SUCCESS upon success, BPM_FAILURE upon failure
*/
int process_diode( bpmconf_t *bpm, bpmsignal_t *sig, bpmproc_t *proc ) {

  double t0;
  char msg[128];

  if ( ! bpm || ! sig || ! proc ) {
    bpm_error( "Invalid pointer arguments in process_diode(...)",
	       __FILE__, __LINE__ );
    return BPM_FAILURE;
  }

  // check whether waveform is really a diode pulse
  if ( bpm->cav_type != diode ) {
    bpm_error( "Invalid configuration type in process_diode(...)", 
	       __FILE__, __LINE__ );
    return BPM_FAILURE;
  }

  if ( sig->wf ) {
    if( fit_diodepulse( sig->wf, bpm->digi_nsamples, bpm->digi_freq, &t0 ) == BPM_FAILURE ) {
      bpm_error( "Could not fit the diode pulse in process_diode(...)", 
		 __FILE__, __LINE__ );
      return BPM_FAILURE;
    } else {
      // update t0, if this routine fails, the value will remain the same as it was before
      proc->t0 = t0;
    }
  } else {
    sprintf( msg, "Invalid signal pointer for %s in process_diode(...)", bpm->name );
    bpm_error( msg, __FILE__, __LINE__ );
    return BPM_FAILURE;
  }

  return BPM_SUCCESS;
}

// end of file
