/**
   @file
   @ingroup processing
*/
#include <bpm/bpm_messages.h>
#include <bpm/bpm_process.h>

/**
   Converts a sample number to a time given the sampling frequency
   
   @param  fs       sampling frequency
   @param  ns       number of samples
   @param  t  the queried sample
   @param  iS  the returned sample time
   
   @return BPM_SUCCESS upon success, BPM_FAILURE upon failure
*/
int sample_to_time( double fs, int ns, int iS, double *t ) {

  if ( iS < 0. ) {
    *t = 0.;
    return BPM_SUCCESS;
  }
  
  if ( iS >= ns ) {
    *t = ( (double) ns - 0.5 ) / fs; // return time of last sample
    return BPM_SUCCESS;
  }

  *t = ( (double) iS + 0.5 ) / fs;
  
  return BPM_SUCCESS;
}
