/**
   @file
   @ingroup sim
*/

#include <bpm/bpm_messages.h>
#include <bpm/bpm_simulation.h>
#include <bpm/bpm_rf.h>
#include <bpm/bpm_nr.h>
#include <bpm/bpm_wf.h>

/**
   Add the given amount of amplitude noise to a complex array
   @param amplnoise The amplitude noise to add to the waveform (in Volts)
   @param IF Complex waveform containing the signal
   @return BPM_SUCCESS upon succes, BPM_FAILURE upon failure
*/
int add_amplnoise( double amplnoise, complexwf_t *IF ) {


  int i;
  double mag, phase;
  complex_t c;
  complexwf_t *noise = complexwf( IF->ns, IF->fs );

  if ( ! IF ) {
    bpm_error( "Invalid pointer arguments in add_amplnoise(...)", 
	       __FILE__, __LINE__ );
    return BPM_FAILURE;
  }

  for ( i = 0; i < IF->ns; i++ ) {
 
     mag = nr_rangauss( 0, amplnoise );
     phase = nr_ranuniform( 0, 2*PI );
     c.re = mag * cos (phase);
     c.im = mag * sin (phase);
     IF->wf[i] = c_sum( IF->wf[i], c );

  }

  complexwf_delete( noise );

  return BPM_SUCCESS;
}

// end of file
