/**
   @file
   @ingroup sim
*/

#include <bpm/bpm_messages.h>
#include <bpm/bpm_simulation.h>
#include <bpm/bpm_rf.h>
#include <bpm/bpm_wf.h>
#include <math.h>

/**
   Generates a one sample impulse to excite the resonator
   @param ttrig the trigger time
   @param RF waveform containing the impulse
   @return BPM_SUCCES upon succes, BPM_FAILURE upon failure
*/
int add_excitation( double ttrig, doublewf_t *RF ) {

  double curr_time = 0;
  int i = 0;

  if ( ! RF ) {
    bpm_error( "Invalid pointer argument in add_wave(...)",
               __FILE__, __LINE__ );
    return BPM_FAILURE;
  }

  while (curr_time < ttrig && i < RF->ns) {
   
    i++;
    curr_time = (double) i / RF->fs;

  }

  RF->wf[i] += 1.;

  return BPM_SUCCESS;
}

// end of file

