/**
   @file
   @ingroup sim
*/

#include <bpm/bpm_simulation.h>

int add_mode_response( complexwf_t *rf, bpmconf_t *bpm, bpmmode_t *mode, beamconf_t *beam ) {

  // add the excitation to the beam rf  
  filter_t    *resonator  = NULL;
  complex_t    amp;
  doublewf_t  *re = NULL;
  doublewf_t  *im = NULL;
  complexwf_t *response = NULL;

  // allocate the excitation wf
  re = doublewf( rf->ns, rf->fs );

  if ( ! re  ) {
    bpm_error( "Unable to allocate memory for buffer in add_mode_response()",
	       __FILE__, __LINE__ );
    return BPM_FAILURE;
  }

  // the arrival time of the beam in the cavity
  // is stored in the beamconf_t structure
  add_excitation( beam->arrival_time, re );

  // mode resonator
  resonator = create_filter( "resonator", RESONATOR | BANDPASS, 0,
			     rf->ns, rf->fs, mode->frequency, 0., mode->Q );
  
  apply_filter( resonator, re->wf );

  doublewf_scale( re->fs/(2*PI*mode->frequency/mode->Q), re );
  im = doublewf_copy_new( re );
  if ( ! im  ) {
    bpm_error( "Unable to allocate memory for buffer in add_mode_response()",
	       __FILE__, __LINE__ );
    doublewf_delete( re );
    return BPM_FAILURE;
  }
  
  doublewf_integrate( re );

  doublewf_scale( 2*PI*mode->frequency, re );

  
  // build the complex response
  response = complexwf( rf->ns, rf->fs );
  if ( ! response  ) {
    bpm_error( "Unable to allocate memory for buffer in add_mode_response()",
	       __FILE__, __LINE__ );
    doublewf_delete( re );
    complexwf_delete( response );
    return BPM_FAILURE;
  }

  complexwf_setreal( response, re );
  complexwf_setimag( response, im );


  // now calculate the complex_t scale factor from the sensitivities
  amp = get_mode_amplitude( bpm, mode, beam );

  // scale the response
  complexwf_scale( amp, response );

  // add the response to the rf
  complexwf_add( rf, response );


  delete_filter( resonator );
  complexwf_delete( response );
  doublewf_delete( re );
  doublewf_delete( im );

  return BPM_SUCCESS;
}
