/**
   @file
*/
#include <bpm/bpm_messages.h>
#include <bpm/bpm_simulation.h>
#include <bpm/bpm_rf.h>
#include <bpm/bpm_wf.h>
#include <bpm/bpm_nr.h>

/**
  Adds a template waveform to the signal with a given scale and rotation
  @param RF the signal
  @param TEMP template waveform to add
  @param f complex number encoding the amplitude and phase
  @return BPM_SUCCESS upon success, BPM_ERROR upon error
*/
int add_waveforms( complexwf_t *RF, complexwf_t *TEMP, complex_t f ) {

  if ( ! RF || ! TEMP ) {
    bpm_error( "Invalid pointer argument in add_wave(...)", 
	       __FILE__, __LINE__ );
    return BPM_FAILURE;
  }

  complexwf_t *Buf = complexwf_copy_new( TEMP );

  complexwf_scale( f, Buf );
  complexwf_add( RF, Buf );

  complexwf_delete( Buf );
 
  return BPM_SUCCESS;
}

// end of file
