/**
   @file
   @ingroup sim
*/

#include <bpm/bpm_simulation.h>

int generate_bpmsignal( bpmconf_t *bpm, beamconf_t *beam, doublewf_t *rf ) {

  int i = 0;
  static char msg[80];
  complexwf_t *rf_compl;
  doublewf_t  *rf_im;

  if ( ! bpm || ! beam || ! rf ) {
    bpm_error( "Invalid pointer arguments in generate_bpmsignal(...)",
               __FILE__, __LINE__ );
    return BPM_FAILURE;
  }

  // reset the rf waveform
  doublewf_reset( rf );

  rf_compl = complexwf( rf->ns, rf->fs );
  rf_im    = doublewf(  rf->ns, rf->fs );
  
  // add all the modes
  for ( i=0; i<bpm->cav_model->nmodes; i++ ) {
    
    if ( add_mode_response( rf_compl, bpm, bpm->cav_model->mode[i], beam ) ) {
      sprintf( msg, "Cannot add response for mode %s in generate_bpmsignal", 
               bpm->cav_model->mode[i]->name );
      bpm_error( msg, __FILE__, __LINE__ );
      return BPM_FAILURE;
    }

  } /* for ( i=0; i<model->nmodes; i++ ) */

  complexwf_getreal( rf,    rf_compl );
  complexwf_getimag( rf_im, rf_compl );
  doublewf_add( rf, rf_im );
 
  complexwf_delete( rf_compl );
  doublewf_delete(  rf_im    );

  return BPM_SUCCESS;
}
