/**
   @file
   @ingroup sim
*/
#include <bpm/bpm_messages.h>
#include <bpm/bpm_simulation.h>
#include <math.h>
#include <bpm/bpm_nr.h>

/**
   Calculate the response of a dipole signal given an incoming bunch
   
   @param bunchcharge The charge of the bunch (in nC)
   @param bunchlength The length of the bunch (in mm)
   @param pos The position of the beam (in mm)
   @param possens The position sensitivty of the BPM (in V/nC/mm)
   @param slope The slope of the beam (in rad)
   @param slopesens The slope sensitivity of the BPM (in V/nC/urad)
   @param tilt The tilt of the bunch (in urad)
   @param tiltsens The tilt sensitivty of the BPM (V/nC/urad)
   @param Amp the complex amplitude of the waveform at the arrival time
*/
int get_dipole_amp( double bunchcharge, double bunchlength,
                    double pos, double possens,
                    double slope, double slopesens,
                    double tilt, double tiltsens,
                    complex_t *Amp ){


  Amp->re =        ( pos   * possens   ) * bunchcharge;
  Amp->im = (-1) * ( slope * slopesens ) * bunchcharge;
  //need to add the tilt

  return BPM_SUCCESS;
}

// end of file
